@@ -5,8 +5,6 @@ try:
 except ImportError:
     import pickle  # type: ignore
 
-from collections import defaultdict
-import functools
 import hashlib
 import json
 import os
@@ -49,11 +47,13 @@ from .pathobjects import (
 from .pbxproject import PBXProject
 from .other import PBXTargetDependency, PBXContainerItemProxy
 from .schemes import Scheme
-from .targets import PBXAggregateTarget, PBXNativeTarget, PBXProductType
+from .targets import PBXAggregateTarget, PBXNativeTarget, PBXProductType, PBXTarget
 from .xcobjects import XCBuildConfiguration, XCConfigurationList
 
 
+# pylint: disable=invalid-name
 PBXObjectType = TypeVar("PBXObjectType", bound=PBXObject)
+# pylint: enable=invalid-name
 
 
 def _load_pbxproj_as_json(path: str) -> Dict[str, Any]:
@@ -122,7 +122,9 @@ class XcodeProject:
         self._set_weak_refs()
 
     @staticmethod
-    def from_cache(project_path: str, *, ignore_deserialization_errors: bool = False) -> "XcodeProject":
+    def from_cache(
+        project_path: str, *, ignore_deserialization_errors: bool = False
+    ) -> "XcodeProject":
         """Attempt to load the project from a cached folder if possible.
 
         :param project_path: The path to the actual project (in case it's a cache miss)
@@ -139,7 +141,9 @@ class XcodeProject:
             with open(os.path.join(cache_folder, f"{project_hash}.dat"), "rb") as cached_file:
                 return pickle.load(cached_file)
         except Exception:
-            return XcodeProject(project_path, ignore_deserialization_errors=ignore_deserialization_errors)
+            return XcodeProject(
+                project_path, ignore_deserialization_errors=ignore_deserialization_errors
+            )
 
     def write_cache(self) -> None:
         """Write out this file to a cache
